ChunkyPipes
===========

.. image:: https://img.shields.io/pypi/v/chunkypipes.svg
    :target: https://pypi.python.org/pypi/chunkypipes/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/chunkypipes.svg
    :target: https://pypi.python.org/pypi/chunkypipes/
    :alt: Downloads

.. image:: https://img.shields.io/pypi/status/chunkypipes.svg
    :target: https://pypi.python.org/pypi/chunkypipes/
    :alt: Status

ChunkyPipes is a framework for easily designing and distributing NGS pipelines written in Python.

Running a pipeline with ChunkyPipes can be as simple as::

    $ chunky install easy-pipeline.py
    $ chunky configure easy-pipeline
    $ chunky run easy-pipeline [arguments]

Read the full documentation `here <http://chunky-pipes.readthedocs.org/en/latest/>`_.